import { type ListCollection, createListCollection } from "../collection";
type ListCollectionOptions<T> = Partial<Parameters<typeof createListCollection<T>>[0]>;
export interface UseListCollectionProps<T> extends ListCollectionOptions<T> {
    /**
     * The initial items to display in the collection.
     */
    initialItems: T[];
    /**
     * The filter function to use to filter the items.
     */
    filter?: (itemText: string, filterText: string) => boolean;
    /**
     * The maximum number of items to display in the collection.
     * Useful for performance when you have a large number of items.
     */
    limit?: number;
}
export declare function useListCollection<T>(props: UseListCollectionProps<T>): {
    collection: ListCollection<T>;
    filter: (inputValue: string) => void;
    set: (items: T[]) => void | undefined;
    reset: () => void | undefined;
    clear: () => void | undefined;
    insert: (index: number, ...items: T[]) => void | undefined;
    insertBefore: (value: string, ...items: T[]) => void | undefined;
    insertAfter: (value: string, ...items: T[]) => void | undefined;
    remove: (...args: T[]) => void | undefined;
    move: (value: string, to: number) => void | undefined;
    moveBefore: (value: string, ...values: string[]) => void | undefined;
    moveAfter: (value: string, ...values: string[]) => void | undefined;
    reorder: (from: number, to: number) => void | undefined;
    append: (...args: T[]) => void | undefined;
    prepend: (...args: T[]) => void | undefined;
    update: (value: string, item: T) => void | undefined;
};
export {};
